@@ -24,20 +24,28 @@ from jpype.types import *
 from typing import List, Optional
 import os, urllib.request, platform
 
-version='2021.1.1'
+version='2022.1.1'
 
 def start_jvm():
     os_str = 'lin64'
     if platform.system() == 'Windows':
         os_str = 'win64'
-    dir_path = os.path.dirname(os.path.realpath(__file__))
-    file_name = "rapidwright-"+version+"-standalone-"+os_str+".jar"
-    classpath = os.path.join(dir_path,file_name)
-    if not os.path.isfile(classpath):
-        url = "http://github.com/Xilinx/RapidWright/releases/download/v"+version+"-beta/" + file_name
-        urllib.request.urlretrieve(url,classpath)
+    kwargs = {}
+    if not os.environ.get('RAPIDWRIGHT_PATH'):
+        dir_path = os.path.dirname(os.path.realpath(__file__))
+        file_name = "rapidwright-"+version+"-standalone-"+os_str+".jar"
+        classpath = os.path.join(dir_path,file_name)
+        if not os.path.isfile(classpath):
+            url = "http://github.com/Xilinx/RapidWright/releases/download/v"+version+"-beta/" + file_name
+            urllib.request.urlretrieve(url,classpath)
+        kwargs['classpath'] = classpath
         
     if not jpype.isJVMStarted():
-        jpype.startJVM(classpath=classpath)
+        jpype.startJVM(**kwargs)
+
+def block_system_exit_calls():
+    from com.xilinx.rapidwright.util import FileTools
+    FileTools.blockSystemExitCalls()
 
 start_jvm()
+block_system_exit_calls()
